@@ -1,21 +1,8 @@
-/*****************************************************************************
- *   Copyright (C) 2009 Ben Cooksley <bcooksley@kde.org>                     *
- *                                                                           *
- *   This program is free software; you can redistribute it and/or modify    *
- *   it under the terms of the GNU General Public License as published by    *
- *   the Free Software Foundation; either version 2 of the License, or       *
- *   (at your option) any later version.                                     *
- *                                                                           *
- *   This program is distributed in the hope that it will be useful,         *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of          *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
- *   GNU General Public License for more details.                            *
- *                                                                           *
- *   You should have received a copy of the GNU General Public License       *
- *   along with this program; if not, write to the                           *
- *   Free Software Foundation, Inc.,                                         *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA            *
- *****************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2009 Ben Cooksley <bcooksley@kde.org>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #ifndef BASEMODE_H
 #define BASEMODE_H
@@ -24,6 +11,8 @@
 
 #include <KPluginMetaData>
 
+#include "systemsettingsview_export.h"
+
 class QAction;
 class MenuItem;
 class ModuleView;
@@ -45,7 +34,7 @@ template<typename T> class QList;
  * @author Ben Cooksley <bcooksley@kde.org>
  * @author Mathias Soeken <msoeken@informatik.uni-bremen.de>
  */
-class Q_DECL_EXPORT BaseMode : public QObject
+class SYSTEMSETTINGSVIEW_EXPORT BaseMode : public QObject
 {
     Q_OBJECT
 
@@ -227,7 +216,7 @@ Q_SIGNALS:
      * of displayed view is changed.
      *
      * @param state Determines whether changes have been made in the view.
-     * @warning Failure to emit this will result in inconsistent application headers and change state.
+     * @warning Failure to Q_EMIT this will result in inconsistent application headers and change state.
      */
     void viewChanged(bool state);
 
