@@ -1,22 +1,9 @@
-/* This file is part of the KDE project
-   Copyright 2007 Will Stephenson <wstephenson@kde.org>
-   Copyright (C) 2009 Ben Cooksley <bcooksley@kde.org>
+/*
+   This file is part of the KDE project
+   SPDX-FileCopyrightText: 2007 Will Stephenson <wstephenson@kde.org>
+   SPDX-FileCopyrightText: 2009 Ben Cooksley <bcooksley@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "MenuItem.h"
@@ -47,7 +34,8 @@ public:
     int weight;
     KService::Ptr service;
     KCModuleInfo item;
-    bool showDefaultIndicator;
+    bool showDefaultIndicator = false;
+    bool isCategoryOwner = false;
 };
 
 MenuItem::MenuItem(bool isMenu, MenuItem *itsParent)
@@ -55,7 +43,6 @@ MenuItem::MenuItem(bool isMenu, MenuItem *itsParent)
 {
     d->parent = itsParent;
     d->menu = isMenu;
-    d->showDefaultIndicator = false;
 
     if (d->parent) {
         d->parent->children().append(this);
@@ -151,6 +138,16 @@ bool MenuItem::showDefaultIndicator() const
     return d->showDefaultIndicator;
 }
 
+bool MenuItem::isCategoryOwner() const
+{
+    return d->isCategoryOwner;
+}
+
+void MenuItem::setCategoryOwner(bool owner)
+{
+    d->isCategoryOwner = owner;
+}
+
 void MenuItem::setItem(const KCModuleInfo &item)
 {
     // d->name = item.moduleName();
@@ -170,12 +167,25 @@ void MenuItem::updateDefaultIndicator()
     }
 }
 
+void MenuItem::setDefaultIndicator(bool defaultIndicator)
+{
+    d->showDefaultIndicator = defaultIndicator;
+    if (menu()) {
+        for (auto child : children()) {
+            d->showDefaultIndicator |= child->showDefaultIndicator();
+        }
+    }
+    if (d->parent) {
+        d->parent->updateDefaultIndicator();
+    }
+}
+
 MenuItem *MenuItem::descendantForModule(const QString &moduleName)
 {
     if (d->service) {
         if (d->service->desktopEntryName() == moduleName) {
             return this;
-        } else if (item().fileName().length() > 0 && item().fileName().split(QLatin1Char('.'), QString::SkipEmptyParts).first() == moduleName) {
+        } else if (item().fileName().length() > 0 && item().fileName().split(QLatin1Char('.'), Qt::SkipEmptyParts).first() == moduleName) {
             return this;
         }
     }
