@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2009 by Ben Cooksley <bcooksley@kde.org>                *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA          *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2009 Ben Cooksley <bcooksley@kde.org>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #ifndef SIDEBARMODE_H
 #define SIDEBARMODE_H
@@ -32,6 +19,7 @@ class QAbstractItemView;
 class QAbstractItemModel;
 class QAction;
 class SidebarMode;
+class MenuItem;
 
 class FocusHackWidget : public QWidget
 {
@@ -143,6 +131,10 @@ private Q_SLOTS:
     void updateDefaults();
     void initWidget();
 
+private:
+    void updateModelMenuItem(MenuItem *item);
+    void updateCategoryModel(const QModelIndex &categoryIdx);
+
 Q_SIGNALS:
     void activeCategoryRowChanged();
     void activeSubCategoryRowChanged();
